@@ -9,10 +9,14 @@ __all__ = [ 'tagClasses', 'tagFormats', 'tagCategories', 'SimpleAsn1Object', \
             'RecordTypeAsn1Object', 'ChoiceTypeAsn1Object', \
             'VariableTypeAsn1Object' ]
 
-from sys import version_info
+try:
+    from sys import version_info
+except ImportError:
+    version_info = (0,0)
 from operator import getslice, setslice, delslice
 from types import *
 from pysnmp.asn1 import error
+from pysnmp.error import PySnmpError
 
 # ASN.1 tagging
 
@@ -182,9 +186,17 @@ class SimpleAsn1Object(Asn1Object):
             return self._cmp(other)
         if type(other) == InstanceType and isinstance(other, SimpleAsn1Object):
             if not isinstance(other, self.__class__):
-                other = self.componentFactoryBorrow(other.get())
+                try:
+                    other = self.componentFactoryBorrow(other.get())
+                except PySnmpError:
+                    # Hide coercion errors
+                    return -1
         else:
-            other = self.componentFactoryBorrow(other)            
+            try:
+                other = self.componentFactoryBorrow(other)
+            except PySnmpError:
+                # Hide coercion errors
+                return -1
         return cmp(self.rawAsn1Value, other.rawAsn1Value)
 
     def __hash__(self):
@@ -326,12 +338,12 @@ class FixedTypeAsn1Object(StructuredAsn1Object):
         if hasattr(self, '_cmp'):
             return self._cmp(other)
 
-        if type(other) != InstanceType or not \
-           isinstance(other, self.__class__):
-            raise error.BadArgumentError('Incompatible types for comparation %s with %s' % (self.__class__.__name__, str(other)))
-
-        return cmp(self._names, other._names) | \
-               cmp(self._components, other._components)
+        if type(other) == InstanceType and isinstance(other, FixedTypeAsn1Object):
+            return cmp(self._names, other._names) | \
+                   cmp(self._components, other._components)
+        else:
+            # Hide coercion errors
+            return -1
 
     def __hash__(self):
         """Returns hash of the payload value
@@ -614,11 +626,12 @@ class VariableTypeAsn1Object(StructuredAsn1Object):
         if hasattr(self, '_cmp'):
             return self._cmp(other)
 
-        if type(other) != InstanceType or not \
-           isinstance(other, self.__class__):
-            raise error.BadArgumentError('Incompatible types for comparation %s with %s' % (self.__class__.__name__, str(other)))
-
-        return cmp(self._components, other._components)
+        if type(other) == InstanceType and \
+               isinstance(other, VariableTypeAsn1Object):
+            return cmp(self._components, other._components)
+        else:
+            # Hide coercion errors
+            return -1
 
     def __hash__(self):
         """Returns hash of the payload value
@@ -703,6 +716,16 @@ class VariableTypeAsn1Object(StructuredAsn1Object):
         self.componentFactoryReturn(self._components[idx])
         del self._components[idx]
 
+    if version_info < (2, 0):
+        # They won't be defined if version is at least 2.0 final
+
+        def __getslice__(self, i, j):
+            return self[max(0, i):max(0, j):]
+        def __setslice__(self, i, j, seq):
+            self[max(0, i):max(0, j):] = seq
+        def __delslice__(self, i, j):
+            del self[max(0, i):max(0, j):]
+
     def append(self, value):
         """Append object to end
         """
