@@ -376,8 +376,9 @@ class OctetString(base.SimpleAsn1Object):
     __rmul__ = __mul__
 
     # They won't be defined if version is at least 2.0 final
-    def __getslice__(self, i, j):
-        return self[max(0, i):max(0, j):]
+    if base.version_info < (2,0):
+        def __getslice__(self, i, j):
+            return self[max(0, i):max(0, j):]
 
 class Null(base.SimpleAsn1Object):
     """ASN.1 NULL object
@@ -385,6 +386,7 @@ class Null(base.SimpleAsn1Object):
     tagId = 0x05
     allowedTypes = [ IntType, LongType, StringType, NoneType ]
     singleValueConstraint = [ 0, 0L, '', None ]
+    initialValue = ''
 
     # Disable not applicible constraints
     _subtype_contained_subtype_constraint = None
@@ -392,6 +394,8 @@ class Null(base.SimpleAsn1Object):
     _subtype_size_constraint = None
     _subtype_permitted_alphabet_constraint = None
 
+    def _iconv(self, value): return ''
+    
 class ObjectIdentifier(base.SimpleAsn1Object):
     """ASN.1 Object ID object (taken and returned as string in conventional
        "dotted" representation)
@@ -459,12 +463,13 @@ class ObjectIdentifier(base.SimpleAsn1Object):
                               self.get())
 
     # They won't be defined if version is at least 2.0 final
-    def __getslice__(self, i, j):
-        return self[max(0, i):max(0, j):]
-    def __setslice__(self, i, j, seq):
-        self[max(0, i):max(0, j):] = seq
-    def __delslice__(self, i, j):
-        del self[max(0, i):max(0, j):]
+    if base.version_info < (2,0):    
+        def __getslice__(self, i, j):
+            return self[max(0, i):max(0, j):]
+        def __setslice__(self, i, j, seq):
+            self[max(0, i):max(0, j):] = seq
+        def __delslice__(self, i, j):
+            del self[max(0, i):max(0, j):]
 
     def append(self, item):
         """Append sub-id with input verification
