@@ -11,6 +11,7 @@ __all__ = [ 'GetRequest', 'GetNextRequest', 'SetRequest', 'Trap', \
 
 from pysnmp.proto.rfc1155 import *
 from pysnmp.proto import rfc1157, error
+from pysnmp.asn1.encoding.ber.error import TypeMismatchError
 
 # These do not require any additional subtyping
 from pysnmp.proto.rfc1157 import VarBind, VarBindList
@@ -20,6 +21,12 @@ class MessageBase(rfc1157.Message):
         # Compatibility stub: initialize PDU type
         apply(rfc1157.Message.__init__, [self], kwargs)
         self['pdu'][None] = self.compatMessagePdu()
+
+    def decode(self, wholeMsg):
+        rest = rfc1157.Message.decode(self, wholeMsg)
+        if not isinstance(self['pdu'].values()[0], self.compatMessagePdu):
+            raise TypeMismatchError('Mismatch PDU type')
+        return rest
         
 class GetRequest(MessageBase): compatMessagePdu = rfc1157.GetRequestPdu
 class GetNextRequest(MessageBase): compatMessagePdu = rfc1157.GetNextRequestPdu
